==> jc-1.4.0.tar.gz: gnu/xml/dom/DomDOMException.h <==
// public class gnu.xml.dom.DomDOMException

// class file dependencies
// @dep_class a9b3c7a682d8b6b2 gnu_xml_dom_DomDOMException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ca80c12995054194 org_w3c_dom_DOMException

// header file dependencies
// @dep_header org_w3c_dom_DOMException

#include "org/w3c/dom/DOMException.h"

#ifndef _JC_gnu_xml_dom_DomDOMException_H_
#define _JC_gnu_xml_dom_DomDOMException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomDOMException$sub_refs	_jc_gnu_xml_dom_DomDOMException$sub_refs;
typedef struct _jc_gnu_xml_dom_DomDOMException$sub_nonrefs	_jc_gnu_xml_dom_DomDOMException$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomDOMException$refs	_jc_gnu_xml_dom_DomDOMException$refs;
typedef struct _jc_gnu_xml_dom_DomDOMException$nonrefs	_jc_gnu_xml_dom_DomDOMException$nonrefs;
typedef struct _jc_gnu_xml_dom_DomDOMException$object	_jc_gnu_xml_dom_DomDOMException$object;

typedef const struct _jc_gnu_xml_dom_DomDOMException$vmethods	_jc_gnu_xml_dom_DomDOMException$vmethods;
typedef const struct _jc_gnu_xml_dom_DomDOMException$vtable	_jc_gnu_xml_dom_DomDOMException$vtable;
typedef const struct _jc_gnu_xml_dom_DomDOMException$vtype	_jc_gnu_xml_dom_DomDOMException$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomDOMException$method$_init$919dbf5c26f3754c(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *, jshort);
extern void _jc_gnu_xml_dom_DomDOMException$method$_init$4f5bc5b71bda187d(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *, jshort, struct _jc_java_lang_String$object *, struct _jc_object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomDOMException$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomDOMException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *);
extern struct _jc_object *_jc_gnu_xml_dom_DomDOMException$method$getNode$07de3e4fb37034a1(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *);
extern jint _jc_gnu_xml_dom_DomDOMException$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomDOMException$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_xml_dom_DomDOMException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_gnu_xml_dom_DomDOMException$method_info$getNode$07de3e4fb37034a1;
extern _jc_method _jc_gnu_xml_dom_DomDOMException$method_info$getValue$245714dca3f59de3;

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomDOMException$method$diagnostic$5240deeae834fba2(_jc_env *, jshort);

// Virtual methods structure
struct _jc_gnu_xml_dom_DomDOMException$vmethods {
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *);
	struct _jc_object	*(*getNode$07de3e4fb37034a1)(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *);
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomDOMException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_DOMException$vmethods	org_w3c_dom_DOMException;
	_jc_gnu_xml_dom_DomDOMException$vmethods	gnu_xml_dom_DomDOMException;
};

// Vtype
struct _jc_gnu_xml_dom_DomDOMException$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomDOMException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDOMException$sub_refs {
	struct _jc_java_lang_String$object	*data;
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomDOMException$refs {
    _jc_gnu_xml_dom_DomDOMException$sub_refs	gnu_xml_dom_DomDOMException;
    _jc_org_w3c_dom_DOMException$sub_refs	org_w3c_dom_DOMException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDOMException$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomDOMException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_DOMException$sub_nonrefs	org_w3c_dom_DOMException;
    _jc_gnu_xml_dom_DomDOMException$sub_nonrefs	gnu_xml_dom_DomDOMException;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomDOMException$object {
	_jc_gnu_xml_dom_DomDOMException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomDOMException$vtype	*vtype;
	_jc_gnu_xml_dom_DomDOMException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomDOMException$vtype _jc_gnu_xml_dom_DomDOMException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomDOMException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomDOMException$class_object;

#endif	/* _JC_gnu_xml_dom_DomDOMException_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomDOMException.h <==
// public class gnu.xml.dom.DomDOMException

// class file dependencies
// @dep_class a9b3c7a682d8b6b2 gnu_xml_dom_DomDOMException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class ca80c12995054194 org_w3c_dom_DOMException

// header file dependencies
// @dep_header org_w3c_dom_DOMException

#include "org/w3c/dom/DOMException.h"

#ifndef _JC_gnu_xml_dom_DomDOMException_H_
#define _JC_gnu_xml_dom_DomDOMException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomDOMException$sub_refs	_jc_gnu_xml_dom_DomDOMException$sub_refs;
typedef struct _jc_gnu_xml_dom_DomDOMException$sub_nonrefs	_jc_gnu_xml_dom_DomDOMException$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomDOMException$refs	_jc_gnu_xml_dom_DomDOMException$refs;
typedef struct _jc_gnu_xml_dom_DomDOMException$nonrefs	_jc_gnu_xml_dom_DomDOMException$nonrefs;
typedef struct _jc_gnu_xml_dom_DomDOMException$object	_jc_gnu_xml_dom_DomDOMException$object;

typedef const struct _jc_gnu_xml_dom_DomDOMException$vmethods	_jc_gnu_xml_dom_DomDOMException$vmethods;
typedef const struct _jc_gnu_xml_dom_DomDOMException$vtable	_jc_gnu_xml_dom_DomDOMException$vtable;
typedef const struct _jc_gnu_xml_dom_DomDOMException$vtype	_jc_gnu_xml_dom_DomDOMException$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomDOMException$method$_init$919dbf5c26f3754c(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *, jshort) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_dom_DomDOMException$method$_init$4f5bc5b71bda187d(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *, jshort, struct _jc_java_lang_String$object *, struct _jc_object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomDOMException$method$getData$bbc608c204d64215(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomDOMException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_dom_DomDOMException$method$getNode$07de3e4fb37034a1(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *) _JC_JCNI_ATTR;
extern jint _jc_gnu_xml_dom_DomDOMException$method$getValue$245714dca3f59de3(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomDOMException$method_info$getData$bbc608c204d64215;
extern _jc_method _jc_gnu_xml_dom_DomDOMException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_gnu_xml_dom_DomDOMException$method_info$getNode$07de3e4fb37034a1;
extern _jc_method _jc_gnu_xml_dom_DomDOMException$method_info$getValue$245714dca3f59de3;

// Static methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomDOMException$method$diagnostic$5240deeae834fba2(_jc_env *, jshort) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomDOMException$vmethods {
	struct _jc_java_lang_String$object	*(*getData$bbc608c204d64215)(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getNode$07de3e4fb37034a1)(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *) _JC_JCNI_ATTR;
	jint	(*getValue$245714dca3f59de3)(_jc_env *, struct _jc_gnu_xml_dom_DomDOMException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomDOMException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_org_w3c_dom_DOMException$vmethods	org_w3c_dom_DOMException;
	_jc_gnu_xml_dom_DomDOMException$vmethods	gnu_xml_dom_DomDOMException;
};

// Vtype
struct _jc_gnu_xml_dom_DomDOMException$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomDOMException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDOMException$sub_refs {
	struct _jc_java_lang_String$object	*data;
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomDOMException$refs {
    _jc_gnu_xml_dom_DomDOMException$sub_refs	gnu_xml_dom_DomDOMException;
    _jc_org_w3c_dom_DOMException$sub_refs	org_w3c_dom_DOMException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomDOMException$sub_nonrefs {
	jint	value;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomDOMException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_org_w3c_dom_DOMException$sub_nonrefs	org_w3c_dom_DOMException;
    _jc_gnu_xml_dom_DomDOMException$sub_nonrefs	gnu_xml_dom_DomDOMException;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomDOMException$object {
	_jc_gnu_xml_dom_DomDOMException$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomDOMException$vtype	*vtype;
	_jc_gnu_xml_dom_DomDOMException$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomDOMException$vtype _jc_gnu_xml_dom_DomDOMException$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomDOMException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomDOMException$class_object;

#endif	/* _JC_gnu_xml_dom_DomDOMException_H_ */
